Pytest-unmarked
============
Allows you to run all unmarked tests

Requirements
============
A recent version of pytest is required (>= 2.3.4).



Running unmarked tests
------------------------------------

Just run py.test with the ``--unmarked`` option to enable.